@@ -20,8 +20,6 @@ from django.utils.functional import Promise
 from django.utils.html import format_html
 from django.utils.safestring import mark_safe
 from django.contrib.admin.templatetags.admin_urls import add_preserved_filters
-from types import MappingProxyType
-
 
 register = template.Library()
 
@@ -292,30 +290,8 @@ def menus(context, _get_config=None):
                 continue
             _app['_weight'] = config.get('menu_display').index(_app['name'])
             display_data.append(_app)
-
-    # if config.get('menu_display') is not None:
-    #     display_data = list()
-    #     for _app in data:
-    #         if _app['name'] not in config.get('menu_display'):
-    #             continue
-    #         # check level 2
-    #         if _app.get('menu_display') is not None:
-    #             display_model = list()
-    #             for _app_m in _app['models']:
-    #                 if _app_m['name'] not in _app.get('menu_display'):
-    #                     continue
-    #                 _app_m['_weight'] = _app.get('menu_display').index(_app_m['name'])
-    #                 display_model.append(_app_m)
-    #         else:
-    #             if 'models' in _app.keys():
-    #                 display_model = _app['models']
-    #
-    #         _app['models'] = display_model
-    #         _app['_weight'] = config.get('menu_display').index(_app['name'])
-    #         display_data.append(_app)
-    #
-    #     display_data.sort(key=lambda x: x['_weight'])
-    #     data = display_data
+        display_data.sort(key=lambda x: x['_weight'])
+        data = display_data
 
     # 给每个菜单增加一个唯一标识，用于tab页判断
     eid = 1000
@@ -553,3 +529,12 @@ def get_previous_url(context):
 @register.simple_tag(takes_context=True)
 def get_verbose_name_plural(context):
     return context['cl'].model._meta.verbose_name_plural
+
+
+@register.simple_tag
+def django_version_is_gte_32x():
+    arrays = django.get_version().split(".")
+    version = []
+    for s in arrays:
+        version.append(int(s))
+    return tuple(version) >= (3, 2)
